@@ -4,10 +4,6 @@ module DiasporaFederation
     #
     # @see Validators::CommentValidator
     class Comment < Entity
-      # Old signature order
-      # @deprecated
-      LEGACY_SIGNATURE_ORDER = %i(guid parent_guid text author).freeze
-
       # The {Comment} parent is a {Post}
       PARENT_TYPE = "Post".freeze
 
@@ -15,12 +11,12 @@ module DiasporaFederation
 
       # @!attribute [r] text
       #   @return [String] the comment text
-      property :text
+      property :text, :string
 
       # @!attribute [r] created_at
       #   Comment entity creation time
       #   @return [Time] creation time
-      property :created_at, default: -> { Time.now.utc }
+      property :created_at, :timestamp, default: -> { Time.now.utc }
     end
   end
 end
