@@ -10,29 +10,21 @@ module DiasporaFederation
       #   The diaspora* ID of the person who share their profile
       #   @see Person#author
       #   @return [String] sender ID
-      property :author, xml_name: :sender_handle
+      property :author, :string, xml_name: :sender_handle
 
       # @!attribute [r] recipient
       #   The diaspora* ID of the person who will be shared with
       #   @see Validation::Rule::DiasporaId
       #   @return [String] recipient ID
-      property :recipient, xml_name: :recipient_handle
+      property :recipient, :string, xml_name: :recipient_handle
 
-      # Use only {Contact} for receive
-      # @return [Contact] instance as contact
-      def to_contact
-        Contact.new(author: author, recipient: recipient)
+      def initialize(*)
+        raise "Sending Request is not supported anymore! Use Contact instead!"
       end
 
-      # @return [String] string representation of this object
-      def to_s
-        "Request:#{author}:#{recipient}"
-      end
-
-      # @param [Nokogiri::XML::Element] root_node xml nodes
       # @return [Retraction] instance
-      private_class_method def self.populate_entity(root_node)
-        super(root_node).to_contact
+      def self.from_hash(hash)
+        Contact.new(hash)
       end
     end
   end
