@@ -13,7 +13,7 @@ module DiasporaFederation
         response = HttpClient.get(url)
         raise "Failed to fetch #{url}: #{response.status}" unless response.success?
 
-        magic_env_xml = Nokogiri::XML::Document.parse(response.body).root
+        magic_env_xml = Nokogiri::XML(response.body).root
         magic_env = Salmon::MagicEnvelope.unenvelop(magic_env_xml)
         Receiver::Public.new(magic_env).receive
       rescue => e
@@ -21,7 +21,7 @@ module DiasporaFederation
       end
 
       private_class_method def self.entity_name(class_name)
-        return class_name if class_name =~ /^[a-z]*(_[a-z]*)*$/
+        return class_name if class_name =~ /\A[a-z]*(_[a-z]*)*\z/
 
         raise DiasporaFederation::Entity::UnknownEntity, class_name unless Entities.const_defined?(class_name)
 
