@@ -15,7 +15,7 @@ module DiasporaFederation
     class MissingHeader < RuntimeError
     end
 
-    # Raised if the decrypted header has an unexpected XML structure
+    # Raised, if the decrypted header has an unexpected XML structure
     # @deprecated
     class InvalidHeader < RuntimeError
     end
@@ -33,6 +33,10 @@ module DiasporaFederation
     class InvalidSignature < RuntimeError
     end
 
+    # Raised, if the parsed Magic Envelope specifies an unhandled data type.
+    class InvalidDataType < RuntimeError
+    end
+
     # Raised, if the parsed Magic Envelope specifies an unhandled algorithm.
     class InvalidAlgorithm < RuntimeError
     end
