@@ -4,7 +4,7 @@ module DiasporaFederation
     class MessageValidator < Validation::Validator
       include Validation
 
-      rule :author, %i(not_empty diaspora_id)
+      rule :author, %i[not_empty diaspora_id]
       rule :guid, :guid
       rule :conversation_guid, :guid
 
