@@ -6,9 +6,9 @@ module DiasporaFederation
 
       rule :guid, :guid
 
-      rule :author, %i(not_empty diaspora_id)
+      rule :author, %i[not_empty diaspora_id]
 
-      rule :url, %i(not_nil URI)
+      rule :url, %i[not_nil URI]
 
       rule :profile, :not_nil
 
