@@ -1,11 +1,12 @@
 module DiasporaFederation
   module Validators
-    # This validates a {Entities::Poll}
+    # This validates a {Entities::Poll}.
     class PollValidator < Validation::Validator
       include Validation
 
       rule :guid, :guid
       rule :question, [:not_empty, length: {maximum: 255}]
+      rule :poll_answers, length: {minimum: 2}
     end
   end
 end
