@@ -4,11 +4,11 @@ module DiasporaFederation
     class ReshareValidator < Validation::Validator
       include Validation
 
-      rule :root_author, %i(not_empty diaspora_id)
+      rule :root_author, %i[not_empty diaspora_id]
 
       rule :root_guid, :guid
 
-      rule :author, %i(not_empty diaspora_id)
+      rule :author, %i[not_empty diaspora_id]
 
       rule :guid, :guid
 
