@@ -4,7 +4,7 @@ module DiasporaFederation
     class RetractionValidator < Validation::Validator
       include Validation
 
-      rule :author, %i(not_empty diaspora_id)
+      rule :author, %i[not_empty diaspora_id]
 
       rule :target_guid, :guid
       rule :target_type, :not_empty
