@@ -4,7 +4,7 @@ module Validation
     #
     # Valid is:
     # * a +String+: "true", "false", "t", "f", "yes", "no", "y", "n", "1", "0"
-    # * a +Fixnum+: 1 or 0
+    # * a +Integer+: 1 or 0
     # * a +Boolean+: true or false
     class Boolean
       # The error key for this rule
@@ -19,9 +19,9 @@ module Validation
 
         if value.is_a?(String)
           true if value =~ /\A(true|false|t|f|yes|no|y|n|1|0)\z/i
-        elsif value.is_a?(Fixnum)
-          true if value == 1 || value == 0
-        elsif [true, false].include? value
+        elsif value.is_a?(Integer)
+          true if [1, 0].include?(value)
+        elsif [true, false].include?(value)
           true
         else
           false
